timeintervaltools.explode_intervals_compactly
=============================================

.. autofunction:: abjad.tools.timeintervaltools.explode_intervals_compactly.explode_intervals_compactly
   :noindex:
